@@ -63,6 +63,10 @@ def docs():
         "[36] ssap.scatter08lrci(df, parameter_x, parameter_y, title)\n"
         "[37] ssap.scatter09lr6sigma(df, parameter_x, parameter_y, sigma, title)\n"
         "[38] ssap.normaltest(targetlist)\n"
+        "[39] ssap.parallel(df, category, title)\n"
+        "[40] ssap.heatmap(df, title)\n"
+        "[41] ssap.matrix01(df, other_matrix_type, upperleft_diag_matrix_type)\n"
+        "[42] ssap.matrix02(df, category, other_matrix_type, upperleft_diag_matrix_type)\n"
 
     )
     # explain details:
@@ -109,9 +113,18 @@ def cmd():
         "[9] set(df) | 'remove duplicate for one parameter'\n"
         "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' \n"
         "[11] pip show (package name) | 'show package details'\n"
-        "[12] data.loc[(data['para1'] == x) & (data['para-3']>xx)]\n"
+        "[12] data.loc[(data['para1'] == x) & (data['para-3']>xx)] | 'filter multiple conditions'\n"
         "[13] df.describe() | 'show dataframe basic statistics values'\n"
         "[14] df.info() | 'show dataframe basic summary'\n"
+        "[15] df.iloc[0,:] | 'select first row'\n"
+        "[16] df.iloc[:,0] | 'select first column'\n"
+        "[17] df.drop([‘column1', ‘column2'], axis=1, inplace=True) | 'drop some columns'\n"
+        "[18] df_test1.sort_values(by=[‘active’], inplace=True, ascending=True/False) | 'sort values'\n"
+        "[19] df.groupby([‘x1’,’x2’]).sum(), xx.reset_index() | 'group by some value'\n"
+        "[20] df3 = df2.stack().rename_axis(('Raws','Feature name')).reset_index(name='xx') | 'stack(),unstack() rows->columns\n'"
+        "[21] random.randint(0,100) for _ in range(20) | random.choice(['type-1','type-2']) for _ in range(20) | 'build some random value'\n"
+        "[22] data.loc[(data['para1'] == x)|(data['para-3']>xx)] | 'filter multiple conditions, or-'|', and-'&''\n"
+        "[xx] xx to be continue.."
     )
 
 
@@ -1619,8 +1632,6 @@ def parallel(df, category, title):
     plt.show()
 
 
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
-
 # heatmap - show correlation of each parameter
 def heatmap(df, title):
     import seaborn as sns
@@ -1723,6 +1734,45 @@ def matrix02(df, category, other_matrix_type, upperleft_diag_matrix_type):
     plt.show()
 
 
+# line chart04-(line plot with error bar. calculate std error by whole sample, or agg value.)
+def line04(df, parameterx, parametery, std_method, gap, title):
+    import numpy as np
+    import matplotlib.pyplot as plt
+
+    df = df
+    df.sort_values(by=[parameterx], inplace=True)
+
+    df_mean = df.groupby(parameterx).mean()
+
+    if std_method == 'm1':
+        df_se = df.groupby(parameterx).agg(np.std)
+    else:
+        df_se = np.std(df[parametery])
+
+    plt.figure()
+    plt.grid(alpha=0.3)
+    x = df_mean.index
+
+    plt.plot(x, df_mean[parametery], '-o', color="white", lw=2, alpha=1, mfc='steelblue')
+    y1_temp = df_mean - df_se
+    y1 = y1_temp[parametery].tolist()
+    y2_temp = df_mean + df_se
+    y2 = y2_temp[parametery].tolist()
+    plt.fill_between(x, y1, y2, color="steelblue")
+
+    plt.xticks(x[::gap], [str(d) for d in x[::gap]], rotation=45)
+    plt.title(title)
+    plt.xlabel(parameterx)
+    plt.ylabel(parametery)
+    plt.show()
+
+
+
+
+warning_threshold = 'Below modules are not validated. update:1/1---------------------👇'
+
+
+
 
 # show correlation line + error zone. with scatter plot:
 
@@ -1731,12 +1781,13 @@ def matrix02(df, category, other_matrix_type, upperleft_diag_matrix_type):
 
 
 # Line plot (x-时间序列: 4.移动平均图 Arima  5.时间序列预测 等种种）
-# my.data analytics ppt里的图表
-# 多因子相关性矩阵图/
-# 用户报告里绘制的图
 # 多项式回归拟合
 # 聚类算法 DBSCAN.
 # regression model:
 # 多元线性回归：https://cloud.tencent.com/developer/article/1059976
 # 移动平均模型（ARIMA）
-# 时间序列预测图：自相关性，异方差性等等
\ No newline at end of file
+# 时间序列预测图：自相关性，偏自相关图等等
+# wordcloud plot(词云图)
+# 贝叶斯统计方法-python实现
+# python自动化爬虫
+# SQL
\ No newline at end of file
